summaryrefslogtreecommitdiffstats
path: root/tdeui/kmainwindowiface.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:13:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:13:01 -0600
commitdeac2ca49faed824fe83066080714eb6d653615b (patch)
tree8b5bf97c5acaaf5285985b87fa76dbea0f35e4fa /tdeui/kmainwindowiface.h
parent0c9d97065a3d6ceb12d687555a1a33d90db96238 (diff)
downloadtdelibs-deac2ca49faed824fe83066080714eb6d653615b.tar.gz
tdelibs-deac2ca49faed824fe83066080714eb6d653615b.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'tdeui/kmainwindowiface.h')
-rw-r--r--tdeui/kmainwindowiface.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/tdeui/kmainwindowiface.h b/tdeui/kmainwindowiface.h
index 58ca74e2c..9ba1c4da9 100644
--- a/tdeui/kmainwindowiface.h
+++ b/tdeui/kmainwindowiface.h
@@ -27,32 +27,32 @@
class KDCOPActionProxy;
class KDCOPPropertyProxy;
-class KMainWindow;
+class TDEMainWindow;
/**
* @short DCOP interface to KMainWindow.
*
* This is the main interface to the KMainWindow. This will provide a consistent
* DCOP interface to all KDE applications that use it.
*
* @author Ian Reinhart Geiser <geiseri@yahoo.com>
*/
-class TDEUI_EXPORT KMainWindowInterface : virtual public DCOPObject
+class TDEUI_EXPORT TDEMainWindowInterface : virtual public DCOPObject
{
K_DCOP
public:
/**
Construct a new interface object.
- @param mainWindow - The parent KMainWindow object
- that will provide us with the KAction objects.
+ @param mainWindow - The parent TDEMainWindow object
+ that will provide us with the TDEAction objects.
*/
- KMainWindowInterface( KMainWindow * mainWindow );
+ TDEMainWindowInterface( TDEMainWindow * mainWindow );
/**
Destructor
Cleans up the dcop action proxy object.
**/
- ~KMainWindowInterface();
+ ~TDEMainWindowInterface();
QCStringList functionsDynamic();
bool processDynamic(const TQCString &fun, const TQByteArray &data, TQCString& replyType, TQByteArray &replyData);
@@ -106,7 +106,7 @@ k_dcop:
TQCString actionToolTip( TQCString action);
/**
- Returns a dcop reference to the selected KAction
+ Returns a dcop reference to the selected TDEAction
@param name The name of the action. The names of valid
actions can be found by calling actions().
@return A DCOPRef for the kaction.
@@ -151,7 +151,7 @@ k_dcop:
// QCStringList getQTProperties();
private:
- KMainWindow *m_MainWindow;
+ TDEMainWindow *m_MainWindow;
KDCOPActionProxy *m_dcopActionProxy;
KDCOPPropertyProxy *m_dcopPropertyProxy;
};
@@ -27,32 +27,32 @@
/**
- * @short DCOP interface to KMainWindow.
+ * @short DCOP interface to TDEMainWindow.
*
@@ -27,32 +27,32 @@
*
- * This is the main interface to the KMainWindow. This will provide a consistent
+ * This is the main interface to the TDEMainWindow. This will provide a consistent
* DCOP interface to all KDE applications that use it.
*